{% extends 'oscar/checkout/preview.html' %}
{% load i18n %}
{% load url from future %}
{% load staticfiles %}
{% load currency_filters %}

{% block payment_method %}
<div class="span6">
	<div class="sub-header">
		<h2>Payment</h2>
	</div>
	<div class="well well-success">
		<p>{{ order_total_incl_tax|currency }} will be debited from your bankcard.</p>
		<div class="alert-actions">
			<a href="{% url "checkout:payment-details" %}" class="btn">Change payment details</a>
		</div>
	</div>
</div>
{% endblock %}

{% block place_order %}
<h3>Please review the information below, then click "Place Order"</h3>

<form id="place-order-form" method="post" action="{{ form_action_url }}">
    <div id="eway-form" style="display: none;">
        {{ bankcard_form }}
    </div>
    <div class="form-actions">
        <button id='place-order' type="submit" value="Place order"
                class="pull-right btn btn-primary btn-large js-disable-on-click">
            {% trans "Place order" %}
        </button>
    </div>
</form>
{% endblock place_order %}
