{% extends 'oscar/checkout/payment_details.html' %}
{% load url from future %}

{% block payment_details_content %}

<form action="{% url "checkout:preview" %}" class="form-stacked" method="POST">
	<table>
		{% csrf_token %}
		{{ bankcard_form.as_table }}
		<tr><td><button type="submit" value="Continue" class="btn btn-primary btn-large">Continue</button></td></tr>
	</table>
</form>

{% endblock %}
